%% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as 
% published by the Free Software Foundation; either version 2 of 
% the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful, 
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
%% popt_i (C) copyright Stephen Duffull ver 1.0; Sept, 2016
%
% EDIT THIS FILE TO SET UP THE MODEL 
%
% See variable_names for a list of reserved variables that should NOT be used in this function
%
% The variables TT [sampling times], THETA [parameter values] and F must be used
%
% PLease note that MATLAB IS case SENSITIVE
%
% Any parametric model can be entered, eg
%		F=d*ka/(v*(ka-k))*(exp(-k*TT).*R1-exp(-ka*TT).*R2);
% use lower case for all variable names and functions and upper case
% for the design points [TT] and the model prediction [F].
%
%% For more instructions see below
%
function [F]=p_model(TT, THETA, D, dn, DI, count_mod, idose)


%% START MODEL  --------------------------

    clp=THETA(1); % CLEARANCE for P-compartment
    vp=THETA(2); % Volume of distribution for P-compartment
    kpm=clp/vp;
    
    clm=THETA(3); % CLEARANCE for M-compartment
    vm=THETA(4); % Volume of distribution for M-compartment
    km0=clm/vm;
    
    d=D(count_mod, idose);      % assignment of dose DO NOT EDIT THIS
    
    F(1,:) = (d/vp)* (exp(-kpm * TT)) ; % Concentration of Parent
    F(2,:) = (d * kpm/ (vm * (kpm - km0))).* (exp(-km0 * TT) - exp(-kpm * TT)); % Concentration of Metabolite
    
    
% END MODEL ------------------------

%% Some further tips:
% As a rule you should always add in an accumulation constant per exponential.  You can then 
% control whether you use these accumulation indices from the POPT_INI.m file.
% When using R1 and R2 (see example code below), then
% you need to use the dot-product rule (see below example for more details).  
% This rule tells MATLAB to compute the product of each element in a vector 
% - rather than use matrix algebra. So R1 is a vector of accumulation indices, 
% one for each sampling time, dn is a vector of dose numbers that each sample is
% to be taken from, so the size of dn = size of TT = size of RR = size
% of di (di is a vector of dose intervals).  
%
%% POPT controls the values of dn, TT, DI, count_model, idose and D
%
% You can either assign parameter variable names to THETA(x) where x corresponds to the
% appropriate value.  Use the same order of parameters as you have in
% popt_ini, eg kpm=THETA(1), cl=THETA(2) etc...; or you can just use THETA(x) in the model code
% as required.
%
% In this example d (dose) must appear as below (with the indices count_mod and idose)
% 
% WARNING Always use a semicolon (;) after every expression - as this
% stops MATLAB echoing the answer to the expression to the screen.

%% DOT product rule
%
% in the above expression "F=d*ka/(v*(ka-k))*(exp(-k*TT).*R1-exp(-ka*TT).*R2)"
% the dot product rule should be observed when you are dealing with vectors - but not scalars
% d, v, ka, k are scalars
% TT, R1, R2 are vectors
% The expression "d*ka/(v*(ka-k))" provides a scalar answer
% The expression "(exp(-k*TT)" provides a vector answer so this expression requires the dot product rule
% 
% You can use the dot product rule for all operations if you wanted ...
% "F=d.*ka./(v.*(ka-k)).*(exp(-k.*TT).*R1-exp(-ka.*TT).*R2)" would also work
%
