%% This version of popt_ini has been designed for informal identifiability 
% analysis of fixed and mixed effects models
%
%% REFERENCES: 
% Shivva, V., Korell, J., Tucker, I.G., Duffull, S.B.  
% An approach for identifiability of population pharmacokinetic
% -pharmacodynamic models. CPT: Pharmacometrics and Syst Pharmacol. 
% (2013) 2(6):e49. doi:  10.1038/psp.2013.25
%
% Shivva, V., Korell, J.K., Tucker, I.G., Duffull, S.B. 
% Parameterisation affects identifiability of population models. 
% J Pharmacokinet Pharmacodyn (2014) 41(1):81-86.
%%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as 
% published by the Free Software Foundation; either version 2 of 
% the License, or (at your option) any later version.
 
% This program is distributed in the hope that it will be useful, 
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.

%%
% POPT (C) copyright Stephen Duffull ver 4.0; Aug, 17th 2011
% PFIM_M (C) copyright Stephen Duffull ver 1.2(i) May; 28th 2003

%% EDIT THIS FILE TO SET UP DESIGN SPECIFICATIONS

% POPT_INI (C) copyright Stephen Duffull ver 4.0; Aug, 17th 2011

% This setup for POPT is for identifiability analysis



%% *********** Identifiability analysis ***********
% This code performs SIA, EDI and IDI analysis
% NB  popt_i cannot distinguish local from global structural identifiability

sia=0; % This is a flag for what sort of identifiability analysis to perform:
% [0 for internal identifiability analysis, 1 for structural identifiability analysis, 2 for observability]

%% IDI analysis (ignore this section if you are doing a SIA analysis)
number_it=500; % if using idi enter the number of random samples (iterations)

% enter the fold range of the parameter values to search over
BETAI_range=5;

max_rse=100; % this is the % maximum allowable RSE

random_method=1; % [0] = non adaptive uniform sampling, [1] = adaptive normal sampling

%% Observability
cv_assay=0.1; % input what you think is a reasonable CV% of your assay


%% *********** MODEL FEATURES **************

mr = 1;
% mr=0 for single response (e.g. PK)
% mr=1 for multiple response (e.g. PKPD)


% Mean population parameter values

BETAI= [ 6 10 1 10]; % 
LowerBETAI = [2 10 0.1 1]; % lower bound for search (IDI only)
UpperBETAI = [12 10 10 10]; % upper bound for search (IDI only)

% Parameter labels
POP_PAR(1,:)=('         CLPM VP CLMO VM'); 

% Mean population parameter values to be considered as fixed constants
% Indicate column position(s) in BETAI to be fixed, if not set FXFI=[]
FXFI=[];

% Between subject variance parameter values
OI=[0.10 0.10 0.10 0.10];

% Between subject variance parameter values to be considered as fixed constants
% Indicate column position(s) in O to be fixed, if not set FXI=[]
% It is required that every component of BETAI has a corresponding value in
% the vector O
FXI=[];

% Model for Between subject variability - each component of O must be
% specified (1=exponential, 0=additive)
BSVMODI=[1 1 1 1];

%% ****************** IDENTIFIABILITY DESIGN *******************

% Number of subjects per elementary design
NUM_SUB=[100]; % number of subjects - generally don't edit this

D=[1000]; % dose - generally don't edit this

expected_halflife=48; % 

number_of_samples=96; % generally don't edit this


